@@ -20,6 +20,7 @@ data structures to things that json can serialize.
 #
 # author Salvo "LtWorf" Tomaselli <tiposchi@tiscali.it>
 
+import datetime
 from enum import Enum
 from typing import *
 
@@ -96,9 +97,11 @@ class Dumper:
             (lambda value: type(value) in self.basictypes, lambda l, value: value),
             (lambda value: isinstance(value, tuple) and hasattr(value, '_fields') and hasattr(value, '_asdict'), _namedtupledump),
             (lambda value: '__dataclass_fields__' in dir(value), _dataclassdump),
-            (lambda value: isinstance(value, (list, tuple, set)), lambda l, value: [l.dump(i) for i in value]),
+            (lambda value: isinstance(value, (list, tuple, set, frozenset)), lambda l, value: [l.dump(i) for i in value]),
             (lambda value: isinstance(value, Enum), lambda l, value: l.dump(value.value)),
             (lambda value: isinstance(value, Dict), lambda l, value: {l.dump(k): l.dump(v) for k, v in value.items()}),
+            (lambda value: isinstance(value, (datetime.date, datetime.time)), _datetimedump),
+
         ]  # type: List[Tuple[Callable[[Any], bool],Callable[['Dumper', Any], Any]]]
 
         for k, v in kwargs.items():
@@ -133,6 +136,18 @@ class Dumper:
         return func(self, value)
 
 
+def _datetimedump(l, value: Union[datetime.time, datetime.date, datetime.datetime]):
+    # datetime is subclass of date
+    if isinstance(value, datetime.date) and not isinstance(value, datetime.datetime):
+        return [value.year, value.month, value.day]
+    if value.tzinfo is not None:
+        raise NotImplemented('Dumping of tzdata object is not supported')
+    if isinstance(value, datetime.time):
+        return [value.hour, value.minute, value.second, value.microsecond]
+    # datetime.datetime
+    return [value.year, value.month, value.day, value.hour, value.minute, value.second, value.microsecond]
+
+
 def _namedtupledump(l, value):
     field_defaults = getattr(value, '_field_defaults', {})
     # Named tuple, skip default values
@@ -149,7 +164,25 @@ def _dataclassdump(l, value):
     field_factories = {k: v.default_factory() for k,v in value.__dataclass_fields__.items() if not isinstance (v.default_factory, dataclasses._MISSING_TYPE)}
     defaults = {**field_defaults, **field_factories} # Merge the two dictionaries
 
-    return {
+    r = {
         f: l.dump(getattr(value, f)) for f in fields
         if not l.hidedefault or f not in defaults or defaults[f] != getattr(value, f)
     }
+
+    #Name mangling
+
+    # Prepare the list of the needed name changes
+    transforms = []  # type: List[Tuple[str, str]]
+    for field in fields:
+        if value.__dataclass_fields__[field].metadata:
+            name = value.__dataclass_fields__[field].metadata.get('name')
+            if name:
+                transforms.append((field, name))
+    # Do the needed name changes
+    if transforms:
+        for pyname, dataname in transforms:
+            if pyname in r:
+                tmp = r[pyname]
+                del r[pyname]
+                r[dataname] = tmp
+    return r
